@@ -12,7 +12,6 @@
 #include <KMessageBox>
 #include <KPasswordDialog>
 #include <kwallet.h>
-#include <kwidgetsaddons_version.h>
 
 #include <QApplication>
 #include <QCommandLineOption>
@@ -237,11 +236,8 @@ static void parsePrompt(const QString &prompt, QString &identifier, bool &ignore
 
 int main(int argc, char **argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("ksshaskpass");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("ksshaskpass"));
 
     // TODO update it.
     KAboutData about(QStringLiteral("ksshaskpass"),
@@ -257,9 +253,6 @@ int main(int argc, char **argv)
     about.addAuthor(i18n("Armin Berres"), i18n("Current author"), QStringLiteral("armin@space-based.de"));
     about.addAuthor(i18n("Hans van Leeuwen"), i18n("Original author"), QStringLiteral("hanz@hanz.nl"));
     about.addAuthor(i18n("Pali Rohár"), i18n("Contributor"), QStringLiteral("pali.rohar@gmail.com"));
-    about.addAuthor(i18n("Armin Berres"), i18n("Current author"), QStringLiteral("armin@space-based.de"), QString());
-    about.addAuthor(i18n("Hans van Leeuwen"), i18n("Original author"), QStringLiteral("hanz@hanz.nl"), QString());
-    about.addAuthor(i18n("Pali Rohár"), i18n("Contributor"), QStringLiteral("pali.rohar@gmail.com"), QString());
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
@@ -315,16 +308,12 @@ int main(int argc, char **argv)
     // Item could not be retrieved from wallet. Open dialog
     switch (type) {
     case TypeConfirm: {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::questionTwoActions(nullptr,
                                             dialog,
                                             i18n("Ksshaskpass"),
                                             KGuiItem(i18nc("@action:button", "Accept"), QStringLiteral("dialog-ok")),
                                             KStandardGuiItem::cancel())
             != KMessageBox::PrimaryAction) {
-#else
-        if (KMessageBox::questionYesNo(nullptr, dialog, i18n("Ksshaskpass")) != KMessageBox::Yes) {
-#endif
             // dialog has been canceled
             return 1;
         }
